import os
from enum import Enum

LINK_MODE = Enum("LINK_MODE", "SKIP OVERRIDE")

DEFAULT_CONFIG_NAME = ".cfgcaddy.yml"

DEFAULT_DOTFILES_DIR = os.path.join(os.path.expanduser("~"), "dotfiles")

HOME_DIR = os.path.expanduser("~")
DEFAULT_CONFIG_PATH = os.path.join(HOME_DIR, DEFAULT_CONFIG_NAME)



from setuptools import setup

setup(
    name='cfgcaddy',
    version='0.1.2',
    description='Tool for managing configuration files',
    url='https://github.com/tstapler/cfgcaddy',
    author='Tyler Stapler',
    author_email='tystapler@gmail.com',
    license='MIT',
    packages=['cfgcaddy'],
    install_requires=[
        "click==6.7",
        "enum34==1.1.6",
        "pathspec==0.5.3",
        "pyyaml==3.12",
        "whaaaaat==0.5.2",
    ],
    entry_points={'console_scripts': ['cfgcaddy = cfgcaddy.__main__:main']},
    zip_safe=True)
